@@ -113,7 +113,7 @@ class ContainerBuilder:
             log.info(
                 'Setting up %s container', self.requested_container_type
             )
-            container_setup = ContainerSetup(
+            container_setup = ContainerSetup.new(
                 self.requested_container_type, self.root_dir,
                 self.container_config
             )
@@ -130,7 +130,7 @@ class ContainerBuilder:
         log.info(
             '--> Creating container image'
         )
-        container_image = ContainerImage(
+        container_image = ContainerImage.new(
             self.requested_container_type, self.root_dir, self.container_config
         )
         self.filename = container_image.create(
