@@ -20,9 +20,7 @@ import os
 import logging
 
 # project
-from kiwi.defaults import Defaults
 from kiwi.command import Command
-from kiwi.utils.sync import DataSync
 from kiwi.path import Path
 from kiwi.package_manager.base import PackageManagerBase
 from kiwi.exceptions import (
@@ -106,13 +104,16 @@ class PackageManagerApt(PackageManagerBase):
             'Package exclusion for (%s) not supported for apt-get', name
         )
 
-    def process_install_requests_bootstrap(self):
+    def process_install_requests_bootstrap(self, root_bind=None):
         """
         Process package install requests for bootstrap phase (no chroot)
         The debootstrap program is used to bootstrap a new system with
         a collection of predefined packages. The kiwi bootstrap section
         information is not used in this case
 
+        :param object root_bind: instance of RootBind to manage kernel
+            file systems before debootstrap call
+
         :raises KiwiDebootstrapError: if no main distribution repository
             is configured, if the debootstrap script is not found or if the
             debootstrap script execution fails
@@ -130,7 +131,17 @@ class PackageManagerApt(PackageManagerBase):
                 'debootstrap script for %s distribution not found' %
                 self.distribution
             )
-        bootstrap_dir = self.root_dir + '.debootstrap'
+
+        # APT package manager does not support bootstrapping. To circumvent
+        # this limitation there is the debootstrap tool for APT based distros.
+        # Because of that there is a little overlap between KIWI and
+        # debootstrap. Debootstrap manages itself the kernel file systems for
+        # chroot environment, thus we need to umount the kernel file systems
+        # before calling debootstrap and remount them afterwards.
+        root_bind.umount_kernel_file_systems()
+        # debootsrap will create its own dev/fd device
+        os.unlink(os.path.normpath(os.sep.join([self.root_dir, 'dev/fd'])))
+
         if 'apt-get' in self.package_requests:
             # debootstrap takes care to install apt-get
             self.package_requests.remove('apt-get')
@@ -143,31 +154,36 @@ class PackageManagerApt(PackageManagerBase):
                 cmd.append('--no-check-gpg')
             if self.deboostrap_minbase:
                 cmd.append('--variant=minbase')
+            if self.package_requests:
+                cmd.append(
+                    '--include={}'.format(','.join(self.package_requests))
+                )
             if self.repository.components:
                 cmd.append(
                     '--components={0}'.format(
                         ','.join(self.repository.components)
                     )
                 )
+            self.cleanup_requests()
             cmd.extend([
-                self.distribution, bootstrap_dir, self.distribution_path
+                self.distribution, self.root_dir, self.distribution_path
             ])
-            Command.run(cmd, self.command_env)
-            data = DataSync(
-                bootstrap_dir + '/', self.root_dir
-            )
-            data.sync_data(
-                options=Defaults.get_sync_options(),
-                exclude=['proc', 'sys', 'dev']
-            )
+
+            return Command.call(cmd, self.command_env)
         except Exception as e:
             raise KiwiDebootstrapError(
                 '%s: %s' % (type(e).__name__, format(e))
             )
-        finally:
-            Path.wipe(bootstrap_dir)
 
-        return self.process_install_requests()
+    def post_process_install_requests_bootstrap(self, root_bind=None):
+        """
+        Mounts the kernel file systems to the chroot environment is
+        ready after the bootstrap procedure
+
+        :param object root_bind:
+            instance of RootBind to manage kernel file systems
+        """
+        root_bind.mount_kernel_file_systems()
 
     def process_install_requests(self):
         """
