@@ -235,7 +235,7 @@ class RepositoryZypper(RepositoryBase):
         prio=None, dist=None, components=None,
         user=None, secret=None, credentials_file=None,
         repo_gpgcheck=None, pkg_gpgcheck=None,
-        sourcetype=None
+        sourcetype=None, use_for_bootstrap=False
     ):
         """
         Add zypper repository
@@ -252,6 +252,7 @@ class RepositoryZypper(RepositoryBase):
         :param bool repo_gpgcheck: enable repository signature validation
         :param bool pkg_gpgcheck: enable package signature validation
         :param str sourcetype: unused
+        :param boot use_for_bootstrap: unused
         """
         if credentials_file:
             repo_secret = os.sep.join(
